* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Importing and Exporting Data](https://help.sap.com/docs/leanix/ea/importing-and-exporting-data)
  * Exporting Workspace Snapshots
